Huggingface Transformers
========================

.. currentmodule:: xpmir.text.huggingface

Encoders
========

.. autoxpmconfig:: TransformerVocab

.. autoxpmconfig:: IndependentTransformerVocab
.. autoxpmconfig:: ContextualizedTextEncoderAdapter
.. autoxpmconfig:: DualTransformerEncoder

Hooks
=====

.. autoxpmconfig:: LayerFreezer
.. autoxpmconfig:: DistributedModelHook
